import * as react_jsx_runtime from 'react/jsx-runtime';
import * as React from 'react';
import { Dispatch, SetStateAction, ReactNode } from 'react';
import { Wallet, Chain, WalletArgsFor } from '@crossmint/wallets-sdk';
import { UIConfig } from '@crossmint/common-sdk-base';
import { CreateOnLogin } from '@crossmint/client-sdk-react-base';
import { PasskeySigner } from '../types/passkey.cjs';
import 'ox';

type ValidPasskeyPromptType = "create-wallet" | "transaction" | "not-supported" | "create-wallet-error" | "transaction-error";
type ValidWalletState = {
    status: "not-loaded";
} | {
    status: "in-progress";
} | {
    status: "error";
    error: Error;
} | {
    status: "loaded";
    wallet: Wallet<Chain>;
};
type WalletContextType = {
    walletState: ValidWalletState;
    setWalletState: Dispatch<SetStateAction<ValidWalletState>>;
    showPasskeyHelpers?: boolean;
    appearance?: UIConfig;
    createPasskeyPrompt: (type: ValidPasskeyPromptType) => () => Promise<void>;
    getOrCreateWallet: <C extends Chain>(args: WalletArgsFor<C>) => Promise<{
        startedCreation: boolean;
        reason?: string;
        wallet?: Wallet<C>;
    }>;
    createPasskeySigner: () => Promise<PasskeySigner>;
    clearWallet: () => void;
};
declare const WalletContext: React.Context<WalletContextType | null>;
declare function useWalletContext(componentName?: string): WalletContextType;
declare function CrossmintWalletProvider({ children, showPasskeyHelpers, appearance, createOnLogin, }: {
    children: ReactNode;
    showPasskeyHelpers?: boolean;
    appearance?: UIConfig;
    createOnLogin?: CreateOnLogin;
}): react_jsx_runtime.JSX.Element;

export { CrossmintWalletProvider, WalletContext, useWalletContext };
